@@ -7,9 +7,7 @@ from argparse import SUPPRESS
 
 import numpy as np
 
-from attractors.anim.gradient import animate_gradient
-from attractors.anim.sim import animate_simulation
-from attractors.utils.base import ATTRACTOR_PARAMS
+from attractors.attractor import ATTRACTOR_PARAMS, Attractor
 
 try:
     import importlib.metadata as metadata
@@ -26,7 +24,7 @@ def case_convert(snakecase_string):
 
 
 def cli():
-    parser = argparse.ArgumentParser(add_help=False)
+    parser = argparse.ArgumentParser(add_help=False, argument_default=argparse.SUPPRESS)
     required = parser.add_argument_group("required arguments")
     optional = parser.add_argument_group("other arguments")
 
@@ -41,7 +39,6 @@ def cli():
         "-h",
         "--help",
         action="help",
-        default=SUPPRESS,
         help="show this help message and exit",
     )
 
@@ -58,7 +55,7 @@ def cli():
         "--des",
         help="choose the Differential Equation Solver. Default: rk4",
         type=str,
-        choices=["euler", "rk2", "rk3", "rk4", "rk5"],
+        choices=Attractor.list_des(),
         default="rk4",
     )
 
@@ -66,19 +63,16 @@ def cli():
         "--width",
         help="set width of the figure Default: 16",
         type=int,
-        default=16,
     )
     optional.add_argument(
         "--height",
         help="set height of the figure Default: 9",
         type=int,
-        default=9,
     )
     optional.add_argument(
         "--dpi",
         help="set DPI of the figure Default: 120",
         type=int,
-        default=120,
     )
     optional.add_argument(
         "--theme", help="choose theme (color palette) to be used", type=str
@@ -117,7 +111,6 @@ def cli():
         "--fps",
         help="set FPS for animated video (or interactive plot) Default: 60",
         type=int,
-        default=60,
     )
     optional.add_argument(
         "--n",
@@ -131,21 +124,19 @@ def cli():
             "method for 2nd order Runge-Kutta if specified to be used." " Default: heun"
         ),
         type=str,
-        default="heun",
         choices=["heun", "imp_poly", "ralston"],
+        default="heun",
     )
     optional.add_argument(
         "--outf",
         help="output video filename Default: output.mp4",
         type=str,
-        default="output.mp4",
     )
     optional.add_argument(
         "--live",
         help="live plotting instead of generating video.",
         action="store_true",
     )
-
     subparsers = parser.add_subparsers(
         title="Attractor settings",
         description="Choose one of the attractors and specify its parameters",
@@ -155,7 +146,9 @@ def cli():
 
     for attr, attrparams in ATTRACTOR_PARAMS.items():
         attrparser = subparsers.add_parser(
-            f"{attr}", help=f"{case_convert(attr)} attractor"
+            f"{attr}",
+            help=f"{case_convert(attr)} attractor",
+            argument_default=argparse.SUPPRESS,
         )
         attrgroup = attrparser.add_argument_group(
             title=f"{case_convert(attr)} attractor parameters"
@@ -169,7 +162,6 @@ def cli():
                     f"Default: {attrparams['default_params'][i]}"
                 ),
                 type=float,
-                default=attrparams["default_params"][i],
             )
         attrgroup.add_argument(
             "--initcoord",
@@ -179,7 +171,6 @@ def cli():
             ),
             type=float,
             nargs=3,
-            default=attrparams["init_coord"],
         )
         for k in ["x", "y", "z"]:
             attrgroup.add_argument(
@@ -190,86 +181,31 @@ def cli():
                 ),
                 type=float,
                 nargs=2,
-                default=attrparams[f"{k}lim"],
             )
 
     args = parser.parse_args()
+    kwargs = vars(args)
 
-    # * load theme
-    raw_themes_data = pkg_resources.open_text(data, "themes.json")
-    themes = json.load(raw_themes_data)
-
-    # * load args
     attractor = args.attractor
-    theme = themes[args.theme] if args.theme is not None else None
-    bgcolor = "#000000"
-    palette = "jet"
-    if theme is not None:
-        palette_temp = list(theme.values())
-        palette_temp.remove(theme["background"])
-        bgcolor = args.bgcolor if args.bgcolor is not None else theme["background"]
-        palette = args.cmap if args.cmap is not None else palette_temp
-    width = args.width
-    height = args.height
-    dpi = args.dpi
-    fps = args.fps
-    simtime = args.simtime
-    simpoints = args.simpoints
-    n = args.n
-    des = args.des
-    rk2_method = args.rk2
-    outf = args.outf
-    live = args.live
-
-    attr = ATTRACTOR_PARAMS[attractor]
-    init_coord = np.array(args.initcoord, dtype="double")
-    attr_params = {p: getattr(args, p) for p in attr["params"]}
-    xlim = args.xlim
-    ylim = args.ylim
-    zlim = args.zlim
-
     if args.type == "multipoint":
-        animate_simulation(
-            attractor,
-            init_coord,
-            attr_params,
-            xlim,
-            ylim,
-            zlim,
-            width,
-            height,
-            dpi,
-            bgcolor,
-            palette,
-            simtime,
-            simpoints,
-            n,
-            des,
-            live,
-            rk2_method,
-            fps,
-            outf,
-        )
+        objs = [Attractor(attractor, kwargs=kwargs) for _ in range(args.n)]
+        for obj in objs:
+            func = getattr(obj, args.des)
+            if args.des == "rk2":
+                func(0, args.simtime, args.simpoints, args.rk2)
+            else:
+                func(0, args.simtime, args.simpoints)
+        update, points, init = Attractor.set_animate_multipoint(*objs, **kwargs)
+        Attractor.animate(update, points, init, **kwargs)
     else:
-        animate_gradient(
-            attractor,
-            init_coord,
-            attr_params,
-            xlim,
-            ylim,
-            zlim,
-            width,
-            height,
-            dpi,
-            bgcolor,
-            palette,
-            simtime,
-            simpoints,
-            des,
-            rk2_method,
-            fps,
-            outf,
-        )
+        obj = Attractor(attractor, kwargs=kwargs)
+        func = getattr(obj, args.des)
+        if args.des == "rk2":
+            func(0, args.simtime, args.simpoints, args.rk2)
+        else:
+            func(0, args.simtime, args.simpoints)
+        update, points, init = Attractor.set_animate_gradient(obj, **kwargs)
+        Attractor.animate(update, points, init, **kwargs)
 
 
 if __name__ == " __main__":
